PageTableMovePlan

Struct PageTableMovePlan 

pub struct PageTableMovePlan<T: TableMeta, A: FrameAllocator> { /* private fields */ }
Allocation-free preimage for one page-table leaf relocation.

A vacant destination must already have all intermediate directories. Use PageTableMapPlan::prepare_path before constructing the final move plan when the destination hierarchy is absent.

Implementations

Source

impl<T: TableMeta, A: FrameAllocator> PageTableMovePlan<T, A>

pub const fn source_vaddr(&self) -> VirtAddr

pub const fn destination_vaddr(&self) -> VirtAddr

pub const fn paddr(&self) -> PhysAddr

pub const fn config(&self) -> PteConfigOf<T>

pub const fn page_size(&self) -> usize

pub const fn destination_is_occupied(&self) -> bool

pub const fn destination_page_size(&self) -> usize